@@ -618,6 +618,11 @@ impl Task {
         self.is_can_running()
     }
 
+    #[inline(always)]
+    pub(crate) fn clear_cylinder_line(&mut self) {
+        self.cylinder_line = 0;
+    }
+
     #[inline(always)]
     /// check if task has arrived.
     pub fn check_arrived(&mut self) -> bool {
